/**  
* Title: CrmController.java 
* Description: 
* @author dsc  
* @date 2020年6月5日  
* @version 1.0  
*/
package cn.timer.api.controller.crm;

import java.util.Date;

import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;

import cn.timer.api.bean.crm.CrmBusinessGroup;
import cn.timer.api.bean.crm.CrmBusinessGroupMember;
import cn.timer.api.bean.crm.CrmClientData;
import cn.timer.api.bean.yggl.YgglMainEmp;
import cn.timer.api.config.annotation.CurrentUser;
import cn.timer.api.config.annotation.UserBean;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

/**
 * Title: CrmController.java
 * 
 * @Description:
 * @author dsc
 * @date 2020年6月5日
 * @version 1.0
 */

@RestController
@Api(tags = "6.1客户管理")
@Transactional
@RequestMapping(value = "/crm", produces = { "application/json" })
public class CrmController {

	private Integer getEmpNum(UserBean userBean) {
		return userBean.getEmpNum();
	}

	private Integer getOrgCode(UserBean userBean) {
		return userBean.getOrgCode();
	}

	@PostMapping("addClient")
	@ApiOperation(value = "新增客户", httpMethod = "POST", notes = "接口发布说明")
	public Result<Object> addClient(@CurrentUser UserBean userBean, @RequestBody CrmClientData crmClientData) {

		crmClientData.setBelongUser(getEmpNum(userBean));
		crmClientData.setOrgCode(getOrgCode(userBean));
		crmClientData.setCreatedTime(new Date());
		return null;
	}

	@PostMapping("addBusinessGroup")
	@Transactional
	@ApiOperation(value = "新增业务组", httpMethod = "POST", notes = "接口发布说明")
	public Result<Object> addBusinessGroup(@CurrentUser UserBean userBean,
			@RequestBody CrmBusinessGroup crmBusinessGroup) {
		Integer orgCode = getOrgCode(userBean);
		Integer empNum = getEmpNum(userBean);
		YgglMainEmp ygglMainEmp = YgglMainEmp.builder().build().selectOne(new QueryWrapper<YgglMainEmp>().lambda()
				.eq(YgglMainEmp::getEmpNum, crmBusinessGroup.getManager()).select(YgglMainEmp::getName));
		if (ygglMainEmp == null)
			return ResultUtil.error("请确认添加的管理员是否存在");
		String name = ygglMainEmp.getName();
		CrmBusinessGroup crmBusinessGroupOld = CrmBusinessGroup.builder().build()
				.selectOne(new QueryWrapper<CrmBusinessGroup>().lambda().eq(CrmBusinessGroup::getOrgCode, orgCode)
						.select(CrmBusinessGroup::getSort).last("limit 1").orderByDesc(CrmBusinessGroup::getId));
		if (crmBusinessGroupOld == null)
			crmBusinessGroup.setSort(1);
		else
			crmBusinessGroup.setSort(crmBusinessGroupOld.getSort() + 1);// 排序
		crmBusinessGroup.setManagerName(name); // 设置管理员姓名
		crmBusinessGroup.setCreateUser(empNum); // 创建人
		crmBusinessGroup.setModifyUser(empNum); // 修改人
		crmBusinessGroup.setOrgCode(orgCode);
//		crmBusinessGroup.setMember(member); // ，字符串拼接
		boolean result = crmBusinessGroup.insert();
		if (!result)
			return ResultUtil.success("保存失败");
		Integer gid = crmBusinessGroup.getId();
		Integer[] ids = crmBusinessGroup.getIds();
		for (Integer empId : ids) {
			CrmBusinessGroupMember.builder().gid(gid).empNum(empId).build().insert();
		}
		return ResultUtil.success("保存成功");
	}

	@GetMapping("getBusinessGroup")
	@ApiOperation(value = "获取业务组列表", httpMethod = "POST", notes = "接口发布说明")
	public Result<Object> getBusinessGroup(@CurrentUser UserBean userBean) {
		return ResultUtil.data(CrmBusinessGroup.builder().build().selectList(
				new QueryWrapper<CrmBusinessGroup>().lambda().eq(CrmBusinessGroup::getOrgCode, getOrgCode(userBean))),
				"获取成功");
	}

	// TODO

}
